Module io.jooby.test
Package io.jooby.test
@ReturnValuesAreNonnullByDefault
package io.jooby.test
Unit test support for Jooby.
-
ClassDescriptionJUnit extension that control lifecycle of Jooby applications on tests.Startup Jooby applications using JUnit extension mechanism.Unit test friendly context implementation.Response generate by
MockRouter.Utility class that allows us to execute routes using aMockContext.Mock session.Access to raw response value fromMockRouteror cast response to something else.Mock implementation ofWebSocketfor unit testing purpose.Websocket client for unit tests.Allow to configure a websocket client for unit tests.