Uses of Class
io.jooby.test.MockWebSocketClient
-
Uses of MockWebSocketClient in io.jooby.test
Methods in io.jooby.test that return MockWebSocketClientModifier and TypeMethodDescriptionMockWebSocketClient.close()Close a websocket and send a close message to websocket server.MockWebSocketClient.close(int code) Close a websocket and send a close message to websocket server.Close a websocket and send a close message to websocket server.MockWebSocketClient.onMessage(SneakyThrows.Consumer<Object> callback) Add an on message callback.Send a websocket message to a websocket server.MockRouter.ws(String path, Consumer<MockWebSocketClient> callback) Execute a GET request and find a websocket, perform the upgrade and produces a websocket client.Method parameters in io.jooby.test with type arguments of type MockWebSocketClientModifier and TypeMethodDescriptionMockRouter.ws(String path, Consumer<MockWebSocketClient> callback) Execute a GET request and find a websocket, perform the upgrade and produces a websocket client.